#ifndef _GROUP_UI_H_
#define _GROUP_UI_H_

#include <pan/base/group.h>

void group_empty_dialog (const GPtrArray * groups);

void group_new_folder_dialog (void);

#endif
